.. include:: definitions.txt

.. _packaging:

Packaging your blocks
=======================

|towrite|



Using ``procgraph_info``
--------------------------

|towrite|



Creating documentation
-----------------------

|towrite|


